////////////////////////////////////////////////////////////////////////////////
//
//	File - AjlDefines.h
//
//	Description -	Contains the AJL API function used to setup all of the parameters
//					In both the User Interface DLL and the AJL Language Monitor.
//					Set the Preprocessor (Project->settings -> C++ tab -> under category choose
//					choose Preprocessor) to one of the following settings depending on
//					the printer:
//					A224x_PRINTER, A21_PRINTER, A756_PRINTER, A793_PRINTER, A794_PRINTER,
//                  A22x_PRINTER
//
//	Copyright:  Axiohm Inc. 1998
//
////////////////////////////////////////////////////////////////////////////////
//
//	Edit History
//
//
/**	
** $Log:   G:/Intersolv/User DLL/AjlDefines.h_v  $
 * 
 *    Rev 1.1   Jun 22 1999 11:05:06   anye
 * Added A22x Printer
 *
** $History: AjlDefines.h $
 * 
 * *****************  Version 11  *****************
 * User: Marty_bifaro Date: 5/05/99    Time: 11:18a
 * Updated in $/Common/User Mode Source/DLL
 * Mods for A224x
 * 
 * *****************  Version 10  *****************
 * User: Marty_bifaro Date: 5/03/99    Time: 4:15p
 * Updated in $/Common/User Mode Source/DLL
 * Creating base code for A224x
 * 
 * *****************  Version 9  *****************
 * User: Marty_bifaro Date: 1/29/99    Time: 3:48p
 * Updated in $/Common/User Mode Source/DLL
 * Added support for full knife cut.
 * Version changed to 2.2
 * 
 * *****************  Version 8  *****************
 * User: Marty_bifaro Date: 1/28/99    Time: 10:58a
 * Updated in $/Common/User Mode Source/DLL
 * Added support for A758
 * 
 * *****************  Version 5  *****************
 * User: Al           Date: 8/14/98    Time: 4:56p
 * Updated in $/Common/User Mode Source/DLL
 * Added K_ESAB_PINGPRINTER enum.
 * 
 * *****************  Version 4  *****************
 * User: Al           Date: 7/21/98    Time: 3:10p
 * Updated in $/Common/User Mode Source/DLL
 * Implemented #define for All printers.
 * 
 * *****************  Version 3  *****************
 * User: Al           Date: 7/21/98    Time: 12:04p
 * Updated in $/Common/User Mode Source/DLL
 * Re-arranged the definitions so that we can provide this file as it is
 * to the customer.
 * 
 * *****************  Version 20  *****************
 * User: Steve        Date: 6/04/98    Time: 9:44a
 * Updated in $/Source/axiohm/NT_dll
 * Added #define MAP_FILE_SIZE and set K_AJL_MAX_READ_BUFFER to that value
 * for win95 version.
 * 
 * *****************  Version 19  *****************
 * User: Steve        Date: 5/20/98    Time: 4:13p
 * Updated in $/Source/axiohm/dll
 * Added new error message K_AJLERROR_CACHE_INVALID
 * 
 * *****************  Version 18  *****************
 * User: Steve        Date: 4/28/98    Time: 5:05p
 * Updated in $/Source/axiohm/dll
 * Added code to support the A721 driver using conditional compiling.  The
 * #ifdefs are A721_PRINTER and A756_PRINTER
 * 
 * *****************  Version 17  *****************
 * User: Steve        Date: 4/27/98    Time: 4:10p
 * Updated in $/Source/axiohm/dll
 * Reordered EASB status Enums
 * 
 * *****************  Version 16  *****************
 * User: Steve        Date: 4/24/98    Time: 4:55p
 * Updated in $/Source/axiohm/dll
 * Rearrange EASB message id's
 * 
 * *****************  Version 15  *****************
 * User: Steve        Date: 4/20/98    Time: 3:07p
 * Updated in $/Source/axiohm/dll
 * Add new sub requests for real time status.
 * 
 * *****************  Version 14  *****************
 * User: Steve        Date: 4/07/98    Time: 5:05p
 * Updated in $/Source/axiohm/dll
 * Added new EASB types for A756
 * 
 * *****************  Version 13  *****************
 * User: Steve        Date: 4/03/98    Time: 4:26p
 * Updated in $/Source/axiohm/dll
 * Continuing modifications for A756
 * 
 * *****************  Version 12  *****************
 * User: Steve        Date: 4/02/98    Time: 5:04p
 * Updated in $/Source/axiohm/dll
 * Continue to make updates for A756
 * 
 * *****************  Version 11  *****************
 * User: Steve        Date: 4/01/98    Time: 5:14p
 * Updated in $/Source/axiohm/dll
 * Continuing modifications for A756
 * 
 * *****************  Version 10  *****************
 * User: Steve        Date: 3/31/98    Time: 5:12p
 * Updated in $/Source/axiohm/dll
 * Updates from A721 to A756 printer
 * 
 * *****************  Version 9  *****************
 * User: Steve        Date: 3/24/98    Time: 4:28p
 * Updated in $/Source/axiohm/dll
 * Original code from A721
 * 
 * *****************  Version 9  *****************
 * User: John         Date: 10/30/97   Time: 10:09a
 * Updated in $/Source/axiohm/dll
 * removed lTrhread
 * 
 * *****************  Version 7  *****************
 * User: John         Date: 10/20/97   Time: 5:40p
 * Updated in $/Source/axiohm/dll
 * fixed errors in how the threads were being handled
 * 
 * *****************  Version 6  *****************
 * User: John         Date: 10/17/97   Time: 7:10a
 * Updated in $/Source/axiohm/dll
 * more bug fixes
 * 
 * *****************  Version 5  *****************
 * User: John         Date: 10/16/97   Time: 10:29a
 * Updated in $/Source/axiohm/dll
 * added K_MICR_NOT_CLAIMED_BY_THIS_APP define
 * 
 * *****************  Version 4  *****************
 * User: John         Date: 10/16/97   Time: 8:32a
 * Updated in $/Source/axiohm/dll
 * 
 * *****************  Version 3  *****************
 * User: John         Date: 10/10/97   Time: 10:18a
 * Updated in $/Source/axiohm/dll
 * major cleanup
 * added notification, micr claim
 * 
 * *****************  Version 2  *****************
 * User: John         Date: 10/07/97   Time: 9:07p
 * Updated in $/Source/App Interface DLL
 * threads worked on extensively
 * claim micr almost finished
 * 
 * *****************  Version 1  *****************
 * User: John         Date: 10/06/97   Time: 11:05a
 * Created in $/Source/App Interface DLL
 * initial entry

**/

#ifndef __AJL_Defines__
#define __AJL_Defines__

#define MAP_FILE_SIZE 1024
#define K_AJL_DLL_THREAD_STACKSIZE  16 * 1024
#define	K_AJLRESPONSEDATA_VERSION	0x00010000
#define	K_AJL_EXTENDED_DATA_LENGTH	128
#define K_AJL_FORMFEEDSTRING	"\f"
#define K_AJL_CARRIAGERETURN	0x0D
#define K_AJL_SPACESTRING	0x20
#define K_AUTO_STATUS_BYTE_COUNT	4
#define K_AJL_MAX_READ_BUFFER		MAP_FILE_SIZE
#define K_NORMAL_BYTE_COUNT			2

// Most of the printers have same functionality as the A756. As you add new printers
// add printer name to the following list.
//
#ifdef AXIOHM_PRINTER
#undef AXIOHM_PRINTER
#endif
#ifdef A756_PRINTER
#define AXIOHM_PRINTER
#endif 
#ifdef A793_PRINTER
#define AXIOHM_PRINTER
#endif 
#ifdef A794_PRINTER
#define AXIOHM_PRINTER
#endif 
#ifdef A758_PRINTER
#define AXIOHM_PRINTER
#endif 
#ifdef A22x_PRINTER
#define AXIOHM_PRINTER
#endif



// types of errors that can be returned by the AJL API functions
//

typedef enum AJLError
{
	K_AJLERROR_NO_ERROR = 0,			// no error has occurred
	K_AJLERROR_MEMORY_ERROR = -1,		// the call failed due to a memory allocation error
	K_AJLERROR_BAD_PARAM = -2,			// one of the parameters for the call was incorrect
	K_AJLERROR_TOO_MANY_PARAMS = -3,	// too many parameters were included in the AJL language call
	K_AJLERROR_TOO_FEW_PARAMS = -4,		// too few parameters were included in the ACL language call
	K_AJLERROR_PRINT_DRIVER = -5,		// an error message was returned by the Print Driver
	K_AJLERROR_INITIALIZE = -6,			// an error message was returned by the Print Driver
	K_AJLERROR_BAD_MODE = -7,			// A mode was specified that is not supported for the 									// command
	K_AJLERROR_NOT_INITIALIZED = -8,	// The AJL system has not been initialized and is not 
										// ready for this call
	K_AJLERROR_INITALREADYCALLED = -9,	// A call to initialize the system has already been made 
	K_AJLERROR_BAD_HDC = -10,			// A NULL HDC was used as a parameter in print mode
	K_AJLERROR_BAD_RESPONSEPTR = -11,	// A NULL response address was specified in print or direct
										// mode
	K_AJLERROR_PIPEWRITEFAILURE = -12,	// A write to the pipe failed
	K_AJLERROR_NOTIFFAILED = -13,		// An attemp to set an event failed
	K_AJLERROR_ESCAPEFAILURE = -14,		// Submitting an escape sequence to the hDC failed
	K_AJLERROR_DEVICE_EXISTS_ON_PORT = -15,	// device exists on port already
	K_AJLERROR_EXCEPTION_THROWN = -16,
	K_AJLERROR_THREAD_INFO_BAD = -17,
	K_AJLERROR_INVALID_HANDLE_VALUE = -18,
	K_AJLERROR_NOTIFICATION_NOT_FOUND = -19,
	K_AJLERROR_MICR_NOT_CLAIMED = -20,
	K_AJLERROR_CACHE_INVALID = -21
}AJLError;

typedef enum AJLResponseError
{
	K_AJLRESPONSEERROR_NO_ERROR = 0,			// no error has occurred
	K_AJLRESPONSEERROR_TIMEOUT = 1,
	K_AJLRESPONSEERROR_SHUTTING_DOWN = 2,
}AJLResponseError;


//
//	defines and data structure for the passage of data from the User Interface DLL to
//	the user application
//	Note that this structure is always allocated by the user app and a pointer
//	to the struture is passed to the DLL through the API calls
//

extern "C"
{
	typedef struct AJLResponseData
	{
		long				messageID;
		long				printerID;
		char				sPrinterName[48];
		long				lThreadID;
		long				structureVersionNumber;
		long				requestType;
		long				requestSubType;
		BOOL				pending;
		HWND				hWnd;
		BOOL				status;
		long				data;
		char				extendedData[K_AJL_EXTENDED_DATA_LENGTH];
		AJLResponseError	error;
		BOOL				needTimer;			// dont need timer by default
		long				timerInitialValue;	// seconds to wait
		long				timerCountDownValue;// timer function iterations
	} AJLResponseData;	
	typedef AJLResponseData *AJLResponseDataPTR;
}



typedef enum AJLMode
{
	K_AJLMODE_PRINT = 0,				// the command is to be sent to the printer by means 
										// of the Windows NT standard Print Architecture
	K_AJLMODE_DIRECT = 1,				// the command is to be sent directly to the language 
										// monitor by means of a named pipe which bypasses 
										//the Windows NT Print Architecture.
	K_AJLMODE_FAST = 2					// The command is to be sent directly to the language 
										//monitor by means of a named pipe and is to be 
										//executed by the language monitor using information 
										//cached in the language monitor.  The printer will not 
										//be directly accessed.
} AJLMode;
 
#ifndef A224x_PRINTER	
typedef enum CashDrawerStatus
{
	LOW = 0,
	HIGH  = 1,
	UNDEFINED = 2
} CashDrawerStatus;

//
// defines the kinds of automatic status back
//
#ifdef A721_PRINTER

typedef enum EASBType
{
	K_ESAB_CASHDRAWEROPEN = 0,		// Enable Automatic Status Back for the cash drawer
	K_ESAB_PRINTERONLINE = 1,		// Enable Automatic Status Back for the printer on and off 									// line
	K_ESAB_PAPERFEEDING = 2,		// Enable Automatic Status Back for active paper feeding 
	K_ESAB_MECHANICALERROR = 3,		// Enable Automatic Status Back to report a mechanical error 		
	K_ESAB_UNRECOVERABLEERROR = 4,	// Enable Automatic Status Back to report the occurrence of a 								// unrecoverable error 	
	K_ESAB_PAPERLOW = 5,			// Enable Automatic Status Back for the paper low sensor 	
	K_ESAB_SLIPPRESENT = 6,			// Enable Automatic Status Back for the slip sensor 	
	K_ESAB_SLIPSELECTED = 7,		// Enable Automatic Status Back for changes in slip selection 	
	K_ESAB_SLIPPRINTABLE = 8,		// Enable Automatic Status Back indication of when a slip can 								// be printed 	
	K_ESAB_VALIDATIONSELECTED = 9,	// Enable Automatic Status Back for changes in validation  									// selection 	
	K_ESAB_VALIDATIONPRINTABLE = 10,	// Enable Automatic Status Back indication of when 										// validation can be printed	
	K_ESAB_PINGPRINTER = 11,			// Printer On/Off Status Back indication of when 										// validation can be printed	
	K_ESAB_END
};
#endif  // A721

#ifdef AXIOHM_PRINTER

typedef enum EASBType
{
	K_ESAB_CASHDRAWEROPEN = 0,		// Enable Automatic Status Back for the cash drawer
	K_ESAB_PRINTERONLINE = 1,		// Enable Automatic Status Back for the printer on and off 									// line
	K_ESAB_PAPERFEEDING = 2,		// Enable Automatic Status Back for active paper feeding 
	K_ESAB_MECHANICALERROR = 3,		// Enable Automatic Status Back to report a mechanical error 		
	K_EASB_KNIFEERROR = 4,
	K_ESAB_UNRECOVERABLEERROR = 5,	// Enable Automatic Status Back to report the occurrence of a 								// unrecoverable error 	
	K_EASB_COVEROPEN = 6,
	K_EASB_GETHEADOVERTEMPERATURE = 7,
	K_ESAB_PAPERLOW = 8,		// Enable Automatic Status Back for the paper low sensor 	
	K_EASB_PAPEREXHAUSTED = 9,
	K_ESAB_SLIPLEADINGPRESENT = 10,			// Enable Automatic Status Back for the slip sensor 	
	K_ESAB_SLIPTRAILINGPRESENT = 11, 
	K_EASB_SLIPPRESENT = 12,
	K_ESAB_SLIPSELECTED = 13,		// Enable Automatic Status Back for changes in slip selection 	
	K_ESAB_SLIPPRINTABLE = 14,		// Enable Automatic Status Back indication of when a slip can 								// be printed 	
	K_ESAB_PINGPRINTER = 15,			// Printer On/Off Status Back indication of when 										// validation can be printed	
	K_ESAB_END
};
#endif  // Axiohm_Printer

// nCmd values used by AJL_RT_SendRealTimeStatus function
enum 
{
	K_AJL_REQSUBTYPE_RT_PRINTER = 1,
	K_AJL_REQSUBTYPE_RT_OFFLINE = 2,
	K_AJL_REQSUBTYPE_RT_ERROR = 3,
	K_AJL_REQSUBTYPE_RT_PAPERLOW = 4,
	K_AJL_REQSUBTYPE_RT_SLIP = 5,
    K_AJL_REQSUBTYPE_RT_PAPERJAM = 6
};

// nCmd values used by AJL_RT_SendRealTimeStatus function
enum 
{
	K_AJL_REQSUBTYPE_RT_RESTART = 1,
	K_AJL_REQSUBTYPE_RT_CLEAR= 2,
	K_AJL_REQSUBTYPE_RT_CANCELSLIPWAITING = 3
};

//Used by MICR function
enum
{
	K_MICR_CLAIMED_BY_THIS_APP = 0,
	K_MICR_CLAIMED_BY_ANOTHER_APP = 1,
	K_MICR_RELEASED = 2,
	K_MICR_CLAIM_FAILED = 3,
	K_MICR_NOT_CLAIMED_BY_THIS_APP = 4
};

#endif  // A224x    
//
//	request Sub Type defines to map back from the general type to the 
//	actual status bit to be returned
enum
{
#ifndef A224x_PRINTER	
	K_AJL_REQSUBTYPE_PAPERLOW = 1,
	K_AJL_REQSUBTYPE_SLIPPRESENT = 2,
	K_AJL_REQSUBTYPE_RT_ISVALPRESENT = 3,
	K_AJL_REQSUBTYPE_RT_WAITINGFORVAL = 4,
	K_AJL_REQSUBTYPE_RT_ISVALSEL = 5,
	K_AJL_REQSUBTYPE_RT_ISSLIPPRESENT = 6,
	K_AJL_REQSUBTYPE_RT_WAITINGFOTSLIP = 7,
	K_AJL_REQSUBTYPE_RT_ISSLIPSELECTED = 8,
	K_AJL_REQSUBTYPE_RT_ISPAPERLOW = 9,
	K_AJL_REQSUBTYPE_RT_UNERROR = 10,
	K_AJL_REQSUBTYPE_RT_MECHERROR = 11,
	K_AJL_REQSUBTYPE_RT_ISPRINTSTOP = 12,
	K_AJL_REQSUBTYPE_RT_ISPAPFEED = 13,
	K_AJL_REQSUBTYPE_RT_ISPRINTON = 14,
	K_AJL_REQSUBTYPE_RT_ISCASHOPEN = 15,
#endif  // A224x    
	K_AJL_REQSUBTYPE_MODELID = 16,
	K_AJL_REQSUBTYPE_TYPEID = 17,
	K_AJL_REQSUBTYPE_ROMVERSION = 18,
#ifndef A224x_PRINTER	
	K_AJL_REQTYPE_MICR_CHANGE_NOTIFY = 19
#endif  // A224x    
};

//
// lengths of data returned from the Language Monitor by type of data
//
enum
{
	K_AJL_DATA_LENGTH_INIT = 1,
	K_AJL_DATA_LENGTH_STATUS = 2,
	K_AJL_DATA_LENGTH_REAL = 2,
	K_AJL_EXCEPTION_DATA_LENGTH = 4,
	K_AJL_DATA_LENGTH_AUTO = 5,
	K_AJL_MICR_CLAIM_LENGTH = 5,
	K_AJL_TICKLE_DATA_LENGTH = 1,
	K_AJL_DATA_LENGTH_ONE = 1
};


// Following are for the test application internal use.
//
// bit defines for status
//

#define K_AJL_STATUS_BIT_PAPERSENSOR_PAPERLOW		0x01
#define K_AJL_STATUS_BIT_PAPERSENSOR_SLIPPRESENT	0x40


//
// defined masks for Automatic Status Back data bytes
//
#ifdef A721_PRINTER

#define K_EASB_MASK_CASHDRAWER		0x04
#define K_EASB_MASK_ONLINE			0x08
#define K_EASB_MASK_COVER			0x20
#define K_EASB_MASK_PAPERFEEDING	0x40
#define K_EASB_MASK_MECHERROR		0x04
#define K_EASB_MASK_UNRECERROR		0x20
#define K_EASB_MASK_PAPERLOW		0x01
#define K_EASB_MASK_SLIPPRESENT		0x20
#define K_EASB_MASK_SLIPSELECTED	0x01
#define K_EASB_MASK_SLIPPRINTABLE	0x02
#define K_EASB_MASK_VALSELECTED		0x04
#define K_EASB_MASK_VALPRINTABLE	0x08

#define K_MASK_JOURNAL_PAPERLOW		0x02
#define K_MASK_VAL_PRESENT			0x40

#endif      // A721

#if defined AXIOHM_PRINTER
// defined masks for Automatic Status Back data bytes
//
// BYTE 1
//  Not used						0x01
//  Not used						0x02
#define K_EASB_MASK_CASHDRAWER		0x04
#define K_EASB_MASK_ONLINE			0x08
//	Not used ( fixed to on )		0x10
#define K_EASB_MASK_COVER			0x20
#define K_EASB_MASK_PAPERFEEDING	0x40
// Not used  ( fixed to off )		0x80

// BYTE 2
//  undefined						0x01
//	undefined						0x02
#define K_EASB_MASK_MECHERROR		0x04
#define K_EASB_MASK_KNIFEERROR		0x08
//  Not used ( fixed to off )		0x10
#define K_EASB_MASK_UNRECERROR		0x20
#define K_EASB_MASK_TEMPERATURE		0x40
//  Not used ( fixed to off )		0x80

// BYTE 3
#define K_EASB_MASK_PAPERLOW		0x01
//  same as bit 0					0x02
#define K_EASB_MASK_PAPEREXHAUSTED	0x04
//  same as bit 3					0x08
//  Not used (fixed to off )		0x10
#define K_EASB_MASK_SLIPPRESENT		 0x20
#define K_EASB_MASK_SLIPPRESENTTRAIL 0x40
//  Not used ( fixed to off )		0x80

// BYTE 4
#define K_EASB_MASK_SLIPSELECTED	0x01
#define K_EASB_MASK_SLIPPRINTABLE   0x02
//  undefined						0x04
//	undefined						0x08
//  Not used ( fixed to off )		0x10
//  undefined						0x20
//  undefined						0x40
//  Not used ( fixed to off )		0x80

#endif  // AXIOHM_PRINTER

#ifndef A224x_PRINTER
typedef enum PFPaper
{
	K_AJLPFPAPER_RECEIPT0 = 0,			// Receipt/Journal paper
	K_AJLPFPAPER_RECEIPT1 = 1,			// Receipt/Journal paper
	K_AJLPFPAPER_SLIP = 2,				// Slip paper
	K_AJLPFPAPER_VALIDATION = 3			// Validation paper
}PFPaper;
#endif  // A224x
#endif
